@@ -8,12 +8,12 @@ stplot = function(obj, names.attr = index(obj@time), ...) {
     else if(is(sp, "SpatialPoints"))
         x = SpatialPointsDataFrame(sp, df)
     else if(is(sp, "SpatialPolygons"))
-        x = SpatialPolygonsDataFrame(sp, df)
+        x = SpatialPolygonsDataFrame(sp, df, match.ID=FALSE)
     else if(is(sp, "SpatialLines"))
-        x = SpatialLinesDataFrame(sp, df)
+        x = SpatialLinesDataFrame(sp, df, match.ID=FALSE)
     else if(is(sp, "SpatialGrid"))
         x = SpatialGridDataFrame(sp, df)
     else
-        stop("obj of unsupported (spatial) class")
+        stop("spatial obj of unsupported class")
     spplot(x, names.attr = names.attr, ...)
 }
